@@ -5,7 +5,7 @@ import sys, os, re, argparse
 sys.path.append(os.path.dirname(__file__))
 
 from PyQt5.QtWidgets import QApplication, QMainWindow, QDialog, \
-    QAbstractScrollArea, QPushButton
+    QAbstractScrollArea, QPushButton, QMessageBox
 from PyQt5.QtCore import QTranslator, QLocale, Qt, pyqtSignal, QLibraryInfo
 
 from ui_live_clone import Ui_MainWindow
@@ -27,6 +27,7 @@ from markdown import markdownFromFile
 from datetime import datetime
 import io
 from subprocess import call
+#from .simul import create_drive, loopDict
 
 # a pattern for the output of dd when copying the ISO image
 # this pattern reports group(1) = bytes copied so far,
@@ -56,6 +57,8 @@ class MyMain(QMainWindow):
         QMainWindow.__init__(self, parent)
         self.lesCles=lesCles
         self.owndisk=owndisk
+        self.loop = ""
+        self.temporary = ""
         self.wd=os.path.abspath(os.path.dirname(__file__))
         self.monitors={}
         self.ui=Ui_MainWindow()
@@ -98,7 +101,7 @@ class MyMain(QMainWindow):
             for d in disks.split(","):
                 result[d]=Tool().runDisk(d, self)
         return result
-
+        
     def cloneAction(self, event):
         """
         Fonction de rappel pour self.ui.toolsButtoncloneButton ; sert à cloner
@@ -228,11 +231,10 @@ class MyMain(QMainWindow):
     def makeRow(self, rindex, disk, already):
         """
         Crée une ligne dans la vue table pour un disque
-        :param index: numéro de la ligne
+        :param rindex: numéro de la ligne
         :param disk: l'instance de disque
         :param already: est Vrai si on sait que la première colonne est déjà
         correcte, et que la ligne existe déjà.
-        :param dic: un dictionnaire disque => partitions
         :return: une nouvelle valeur pour l'index, augmentée si une ligne a été
         créée.
         """
@@ -390,7 +392,7 @@ def main():
         # if we have ['sda1', 'sda3'], this should give "sda"
         ownDisk=shortDiskNames[0][:-1]
     if args.diskinstall:
-        ## lauch the GUI for hard disk install
+        ## launch the GUI for hard disk install
         w = HardDiskMain(ownDisk)
     else:
         w = MyMain(lesCles, ownDisk)
