@@ -5,6 +5,7 @@ from subprocess import Popen, PIPE, call, run
 from PyQt5.QtCore import QObject, QTranslator, QLocale
 from PyQt5.QtWidgets import QApplication
 from ensure import ensure
+from ownsense import ownDevice
 
 def disksize(device_short, disktype = "disk"):
     """
@@ -29,24 +30,6 @@ def disksize(device_short, disktype = "disk"):
     size = completed.stdout.strip()
     return int(size)
 
-def ownDevice(blockSize = 4194304):
-    """
-    Find the device path of the USB stick itself, when cloning in "own" mode
-    
-    @param blockSize the size of wanted blocks; defaults to 4194304 == 4M
-    @return the path of the USB stick's device and its size in blocks unit
-    """
-    try:
-        mountpoint = glob.glob("/usr/lib/live/mount/persistence/sd*")[0]
-    except:
-        mountpoint = "/usr/lib/live/mount/persistence/sda1"
-    device = re.sub(
-        r"/usr/lib/live/mount/persistence/(sd.)1", r"/dev/\1", mountpoint)
-    cmd=f"sfdisk -l {device}| grep /dev/sd.1| awk '{{print $4}}'"
-    completed = run(cmd, shell=True, capture_output=True, encoding="utf-8")
-    sectors=int(completed.stdout.strip())
-    count = 1 + sectors*512//blockSize # convert 512 B sectors to 4 MiB blocks
-    return device, count
 
 class StickMaker(QObject):
     def __init__(self):
